
<!-- README.md is generated from README.Rmd. Please edit that file -->

# pyks

<!-- badges: start -->

[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/version.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/latest_release_date.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/platforms.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/license.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/downloads.svg)](https://anaconda.org/jiaxiangbu/pyks)
[![Anaconda-Server
Badge](https://anaconda.org/jiaxiangbu/pyks/badges/installer/conda.svg)](https://conda.anaconda.org/jiaxiangbu)
[![DOI](https://zenodo.org/badge/197245838.svg)](https://zenodo.org/badge/latestdoi/197245838)
[![PyPI
version](https://badge.fury.io/py/pyks.svg)](https://badge.fury.io/py/pyks)
<!-- badges: end -->

The goal of `pyks` is to help do calculation KS statistic for a model.
The R version [rawKS](https://github.com/JiaxiangBU/rawKS) is hosted
from GitHub.

## Installation

You can install the released version of `pyks` from [Anaconda
Cloud](https://anaconda.org/JiaxiangBU/pyks) with:

``` conda
conda install -c jiaxiangbu pyks 
```

or the released version of `pyks` from [Python Package
Index](https://pypi.org/project/pyks/) with:

``` conda
pip install pyks
```

or the development version from [GitHub](https://github.com/) with:

``` conda
pip install git+https://github.com/JiaxiangBU/pyks
```

## Citations

If you use pyks, I would be very grateful if you can add a citation in
your published work. By citing pyks, beyond acknowledging the work, you
contribute to make it more visible and guarantee its growing and
sustainability. For citation, please use the BibTex or the citation
content.

``` bibtex
@misc{jiaxiang_li_2019_3351276,
  author       = {Jiaxiang Li},
  title        = {JiaxiangBU/pyks: pyks 1.1.3},
  month        = jul,
  year         = 2019,
  doi          = {10.5281/zenodo.3351276},
  url          = {https://doi.org/10.5281/zenodo.3351276}
}
```

Jiaxiang Li. (2019, July 25). JiaxiangBU/pyks: pyks 1.1.3 (Version
v1.1.3). Zenodo. <http://doi.org/10.5281/zenodo.3351276>

## Disclaimers

<h4 align="center">

**Code of Conduct**

</h4>

<h6 align="center">

Please note that the `pyks` project is released with a [Contributor Code
of Conduct](.github/CODE_OF_CONDUCT.md).<br>By contributing to this
project, you agree to abide by its terms.

</h6>

<h4 align="center">

**License**

</h4>

<h6 align="center">

MIT © [Jiaxiang Li](LICENSE.md)

</h6>
